==> mauticGIT-Test-20251212_104643.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/52/52d75a9175e0d632eace8f789c638ba8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fpoe_kaernten_theme_full_final_v2/assets/ig-white.png */
class __TwigTemplate_2ba2d05871d5e930470395810bad6bb2 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000!\000\000\000!\000\000\000Wo\000\000\000sBIT|d\000\000IDATXG͗Q1xM,\"rW+ 8O&MIS=BEWvVjuZV6W-h|q#5J(c.H94)Z;\000D`B@qf塸\000kY|7s&ĕsƶRp.5L^Hњ#\$Y> htZ\$.\$3ZVeF|S
v^;W~je!.A;w |\000_C\000A}A(R|:5\tA\000ģ~_@lF2(v.'=rZ:\000Ut=\tn1< <H'n|gh
@C)E]_}C) l%mmQS@pou k8%f9,18{bw,wpyh%l`%tP@,Ԧh}i,RHC.qKa\"\\a~{.Ѧh2Ebz{!Wܙ4CޑlJRx
ܖYZrH 4MlB!JJ}]\000`AM?j\t\000p҂}`=\\r/5J#UIg`dxz>e!{Q2#7u1Mx5h=Sf*>1Ҟ\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fpoe_kaernten_theme_full_final_v2/assets/ig-white.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/assets/ig-white.png", "/var/www/mautic-ktn/themes/fpoe_kaernten_theme_full_final_v2/assets/ig-white.png");
    }
}

==> mauticGIT-Test-20260116_092227.tar.gz: var/www/html/mauticGIT-Test/var/tmp/twig/52/52d75a9175e0d632eace8f789c638ba8.php <==
<?php

use Twig\Environment;
use Twig\Error\LoaderError;
use Twig\Error\RuntimeError;
use Twig\Extension\CoreExtension;
use Twig\Extension\SandboxExtension;
use Twig\Markup;
use Twig\Sandbox\SecurityError;
use Twig\Sandbox\SecurityNotAllowedTagError;
use Twig\Sandbox\SecurityNotAllowedFilterError;
use Twig\Sandbox\SecurityNotAllowedFunctionError;
use Twig\Source;
use Twig\Template;
use Twig\TemplateWrapper;

/* @themes/fpoe_kaernten_theme_full_final_v2/assets/ig-white.png */
class __TwigTemplate_2ba2d05871d5e930470395810bad6bb2 extends Template
{
    private Source $source;
    /**
     * @var array<string, Template>
     */
    private array $macros = [];

    public function __construct(Environment $env)
    {
        parent::__construct($env);

        $this->source = $this->getSourceContext();

        $this->parent = false;

        $this->blocks = [
        ];
    }

    protected function doDisplay(array $context, array $blocks = []): iterable
    {
        $macros = $this->macros;
        // line 1
        yield "PNG

\000\000\000
IHDR\000\000\000!\000\000\000!\000\000\000Wo\000\000\000sBIT|d\000\000IDATXG͗Q1xM,\"rW+ 8O&MIS=BEWvVjuZV6W-h|q#5J(c.H94)Z;\000D`B@qf塸\000kY|7s&ĕsƶRp.5L^Hњ#\$Y> htZ\$.\$3ZVeF|S
v^;W~je!.A;w |\000_C\000A}A(R|:5\tA\000ģ~_@lF2(v.'=rZ:\000Ut=\tn1< <H'n|gh
@C)E]_}C) l%mmQS@pou k8%f9,18{bw,wpyh%l`%tP@,Ԧh}i,RHC.qKa\"\\a~{.Ѧh2Ebz{!Wܙ4CޑlJRx
ܖYZrH 4MlB!JJ}]\000`AM?j\t\000p҂}`=\\r/5J#UIg`dxz>e!{Q2#7u1Mx5h=Sf*>1Ҟ\000\000\000\000IENDB`";
        yield from [];
    }

    /**
     * @codeCoverageIgnore
     */
    public function getTemplateName(): string
    {
        return "@themes/fpoe_kaernten_theme_full_final_v2/assets/ig-white.png";
    }

    /**
     * @codeCoverageIgnore
     */
    public function getDebugInfo(): array
    {
        return array (  42 => 1,);
    }

    public function getSourceContext(): Source
    {
        return new Source("", "@themes/fpoe_kaernten_theme_full_final_v2/assets/ig-white.png", "/var/www/html/mauticGIT-Test/themes/fpoe_kaernten_theme_full_final_v2/assets/ig-white.png");
    }
}
